/* 
 * Copyright (C) 2015 Martin Gräßlin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef IDLE_CLIENT_PROTOCOL_H
#define IDLE_CLIENT_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_idle;
struct org_kde_kwin_idle_timeout;
struct wl_seat;

extern const struct wl_interface org_kde_kwin_idle_interface;
extern const struct wl_interface org_kde_kwin_idle_timeout_interface;

#define ORG_KDE_KWIN_IDLE_GET_IDLE_TIMEOUT	0

static inline void
org_kde_kwin_idle_set_user_data(struct org_kde_kwin_idle *org_kde_kwin_idle, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_idle, user_data);
}

static inline void *
org_kde_kwin_idle_get_user_data(struct org_kde_kwin_idle *org_kde_kwin_idle)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_idle);
}

static inline void
org_kde_kwin_idle_destroy(struct org_kde_kwin_idle *org_kde_kwin_idle)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_idle);
}

static inline struct org_kde_kwin_idle_timeout *
org_kde_kwin_idle_get_idle_timeout(struct org_kde_kwin_idle *org_kde_kwin_idle, struct wl_seat *seat, uint32_t timeout)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_constructor((struct wl_proxy *) org_kde_kwin_idle,
			 ORG_KDE_KWIN_IDLE_GET_IDLE_TIMEOUT, &org_kde_kwin_idle_timeout_interface, NULL, seat, timeout);

	return (struct org_kde_kwin_idle_timeout *) id;
}

struct org_kde_kwin_idle_timeout_listener {
	/**
	 * idle - Triggered when there has not been any user activity for
	 *	the requested time
	 *
	 * 
	 */
	void (*idle)(void *data,
		     struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout);
	/**
	 * resumed - Triggered on the first user activity after an idle
	 *	event
	 *
	 * 
	 */
	void (*resumed)(void *data,
			struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout);
};

static inline int
org_kde_kwin_idle_timeout_add_listener(struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout,
				       const struct org_kde_kwin_idle_timeout_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) org_kde_kwin_idle_timeout,
				     (void (**)(void)) listener, data);
}

#define ORG_KDE_KWIN_IDLE_TIMEOUT_RELEASE	0
#define ORG_KDE_KWIN_IDLE_TIMEOUT_SIMULATE_USER_ACTIVITY	1

static inline void
org_kde_kwin_idle_timeout_set_user_data(struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) org_kde_kwin_idle_timeout, user_data);
}

static inline void *
org_kde_kwin_idle_timeout_get_user_data(struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout)
{
	return wl_proxy_get_user_data((struct wl_proxy *) org_kde_kwin_idle_timeout);
}

static inline void
org_kde_kwin_idle_timeout_destroy(struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout)
{
	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_idle_timeout);
}

static inline void
org_kde_kwin_idle_timeout_release(struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_idle_timeout,
			 ORG_KDE_KWIN_IDLE_TIMEOUT_RELEASE);

	wl_proxy_destroy((struct wl_proxy *) org_kde_kwin_idle_timeout);
}

static inline void
org_kde_kwin_idle_timeout_simulate_user_activity(struct org_kde_kwin_idle_timeout *org_kde_kwin_idle_timeout)
{
	wl_proxy_marshal((struct wl_proxy *) org_kde_kwin_idle_timeout,
			 ORG_KDE_KWIN_IDLE_TIMEOUT_SIMULATE_USER_ACTIVITY);
}

#ifdef  __cplusplus
}
#endif

#endif
