/* 
 * Copyright (C) 2015 Martin Gräßlin
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SHADOW_SERVER_PROTOCOL_H
#define SHADOW_SERVER_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stddef.h>
#include "wayland-server.h"

struct wl_client;
struct wl_resource;

struct org_kde_kwin_shadow;
struct org_kde_kwin_shadow_manager;
struct wl_buffer;
struct wl_surface;

extern const struct wl_interface org_kde_kwin_shadow_manager_interface;
extern const struct wl_interface org_kde_kwin_shadow_interface;

struct org_kde_kwin_shadow_manager_interface {
	/**
	 * create - (none)
	 * @id: (none)
	 * @surface: (none)
	 */
	void (*create)(struct wl_client *client,
		       struct wl_resource *resource,
		       uint32_t id,
		       struct wl_resource *surface);
	/**
	 * unset - (none)
	 * @surface: (none)
	 */
	void (*unset)(struct wl_client *client,
		      struct wl_resource *resource,
		      struct wl_resource *surface);
};


struct org_kde_kwin_shadow_interface {
	/**
	 * commit - (none)
	 */
	void (*commit)(struct wl_client *client,
		       struct wl_resource *resource);
	/**
	 * attach_left - (none)
	 * @buffer: (none)
	 */
	void (*attach_left)(struct wl_client *client,
			    struct wl_resource *resource,
			    struct wl_resource *buffer);
	/**
	 * attach_top_left - (none)
	 * @buffer: (none)
	 */
	void (*attach_top_left)(struct wl_client *client,
				struct wl_resource *resource,
				struct wl_resource *buffer);
	/**
	 * attach_top - (none)
	 * @buffer: (none)
	 */
	void (*attach_top)(struct wl_client *client,
			   struct wl_resource *resource,
			   struct wl_resource *buffer);
	/**
	 * attach_top_right - (none)
	 * @buffer: (none)
	 */
	void (*attach_top_right)(struct wl_client *client,
				 struct wl_resource *resource,
				 struct wl_resource *buffer);
	/**
	 * attach_right - (none)
	 * @buffer: (none)
	 */
	void (*attach_right)(struct wl_client *client,
			     struct wl_resource *resource,
			     struct wl_resource *buffer);
	/**
	 * attach_bottom_right - (none)
	 * @buffer: (none)
	 */
	void (*attach_bottom_right)(struct wl_client *client,
				    struct wl_resource *resource,
				    struct wl_resource *buffer);
	/**
	 * attach_bottom - (none)
	 * @buffer: (none)
	 */
	void (*attach_bottom)(struct wl_client *client,
			      struct wl_resource *resource,
			      struct wl_resource *buffer);
	/**
	 * attach_bottom_left - (none)
	 * @buffer: (none)
	 */
	void (*attach_bottom_left)(struct wl_client *client,
				   struct wl_resource *resource,
				   struct wl_resource *buffer);
	/**
	 * set_left_offset - (none)
	 * @offset: (none)
	 */
	void (*set_left_offset)(struct wl_client *client,
				struct wl_resource *resource,
				wl_fixed_t offset);
	/**
	 * set_top_offset - (none)
	 * @offset: (none)
	 */
	void (*set_top_offset)(struct wl_client *client,
			       struct wl_resource *resource,
			       wl_fixed_t offset);
	/**
	 * set_right_offset - (none)
	 * @offset: (none)
	 */
	void (*set_right_offset)(struct wl_client *client,
				 struct wl_resource *resource,
				 wl_fixed_t offset);
	/**
	 * set_bottom_offset - (none)
	 * @offset: (none)
	 */
	void (*set_bottom_offset)(struct wl_client *client,
				  struct wl_resource *resource,
				  wl_fixed_t offset);
};


#ifdef  __cplusplus
}
#endif

#endif
